import React from "react";
import { Table } from "@ess-ics/ce-ui-common";
import { JobStatusColumn } from "./JobStatusColumn";
import { JobSummary } from "./JobSummary";
import { UserAvatar } from "../../common/User/UserAvatar";
import { Link } from "@mui/material";

const jobLogColumns = [
  {
    field: "status",
    headerName: "Status"
  },
  {
    field: "job",
    headerName: "Job"
  },
  {
    field: "host",
    headerName: "Host"
  },
  {
    field: "user",
    headerName: "User",
    align: "center",
    headerAlign: "center"
  }
];

const userPageJobLogColumns = [
  ...jobLogColumns.filter((it) => it.field !== "user")
];

function createTableRow(job, colorStyle) {
  return {
    id: job.id,
    status: <JobStatusColumn {...{ job }} />,
    job: <JobSummary {...{ job, colorStyle }} />,
    host: job.host?.hostName ? (
      <Link
        href={`/hosts/${job?.host?.externalHostId}`}
        aria-label={`Host ${job.host?.hostName}`}
      >
        {job.host?.hostName}
      </Link>
    ) : null,
    user: <UserAvatar username={job.createdBy} />
  };
}

function createTableRowJobLog(job) {
  return createTableRow(job, "black");
}

export function JobTable({
  jobs,
  rowType = "jobLog",
  pagination,
  onPage,
  loading
}) {
  const tableTypeSpecifics = {
    jobLog: [jobLogColumns, createTableRowJobLog],
    userPageJobLog: [userPageJobLogColumns, createTableRowJobLog]
  };

  const [columns, createRow] = tableTypeSpecifics[rowType];

  return (
    <Table
      columns={columns}
      rows={jobs?.map((job) => createRow(job))}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
      rowHeight={90}
    />
  );
}
